@@ -64,6 +64,7 @@ class Form(object):
     
     fields = {}
     status = None
+    prefix = None
     
     def __init__(self, data=None, context=None, request=None, prefix=None):
         self.context = context
@@ -78,11 +79,14 @@ class Form(object):
             data = Proxy(context)
 
         self.data = Data(data)
-        
+
+        if prefix is None:
+            prefix = self.prefix
+            
         # find action parameters
+        action_params = {}
         if prefix is not None:
             re_prefix = re.compile(r'^%s[._-](?P<name>.*)' % prefix)
-            action_params = {}
             for key, value in request.params.items():
                 if key == prefix:
                     action_params[None] = value
